@@ -67,17 +67,14 @@ mysql --socket=${MYTEMP_DIR}/mysql.sock --execute="CREATE DATABASE test_pymysql2
 #####################
 ### RUN THE TESTS ###
 #####################
+MULTI_STATEMENTS=$(python3 -c 'from pymysql.constants import CLIENT ; print(CLIENT.MULTI_STATEMENTS)')
 # Launch the tests
 echo "[
-{\"unix_socket\": \"${MYTEMP_DIR}/mysql.sock\", \"user\": \"root\", \"passwd\": \"\", \"db\": \"test_pymysql\", \"use_unicode\": true},
-{\"unix_socket\": \"${MYTEMP_DIR}/mysql.sock\", \"user\": \"root\", \"passwd\": \"\", \"db\": \"test_pymysql2\" }
+{\"unix_socket\": \"${MYTEMP_DIR}/mysql.sock\", \"user\": \"root\", \"passwd\": \"\", \"db\": \"test_pymysql\", \"use_unicode\": true, \"client_flag\": $MULTI_STATEMENTS},
+{\"unix_socket\": \"${MYTEMP_DIR}/mysql.sock\", \"user\": \"root\", \"passwd\": \"\", \"db\": \"test_pymysql2\", \"client_flag\": $MULTI_STATEMENTS }
 ]" >pymysql/tests/databases.json
 
-PYTHONS=`pyversions -vr`
-PYTHON3S=`py3versions -vr`
-for pyvers in $PYTHONS $PYTHON3S; do
-	PYTHONPATH=. PYTHON=python$pyvers python$pyvers runtests.py
-done
+PYTHONPATH=. PYTHON=$1 $1 runtests.py
 
 rm pymysql/tests/databases.json
 
